---
id: 20211123213414
title: List references in card's footer
tags: [template, zettel, markdown]
---

# List references in card's footer

Optionally, markdown documents may contain a footer delimited by `---`. This is equivalent of [yaml frontmatter](https://www.mkdocs.org/user-guide/writing-your-docs/#yaml-style-meta-data). The content of this block will be rendered in card's footer as a list of `References`.

In case [backlinks were found](20211123214904) for the document, there will be an additional list called `Backlinks`.

See also the [references and backlinks test](20260218000001).
